==> openshift-model-monitoring-5.10.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/WeChatConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.SecretKeySelector;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class WeChatConfigFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfigFluent<A>{
  public WeChatConfigFluentImpl() {
  }
  public WeChatConfigFluentImpl(io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfig instance) {
    this.withAgentID(instance.getAgentID()); 
    this.withApiSecret(instance.getApiSecret()); 
    this.withApiURL(instance.getApiURL()); 
    this.withCorpID(instance.getCorpID()); 
    this.withHttpConfig(instance.getHttpConfig()); 
    this.withMessage(instance.getMessage()); 
    this.withMessageType(instance.getMessageType()); 
    this.withSendResolved(instance.getSendResolved()); 
    this.withToParty(instance.getToParty()); 
    this.withToTag(instance.getToTag()); 
    this.withToUser(instance.getToUser()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String agentID;
  private io.fabric8.kubernetes.api.model.SecretKeySelector apiSecret;
  private java.lang.String apiURL;
  private java.lang.String corpID;
  private io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder httpConfig;
  private java.lang.String message;
  private java.lang.String messageType;
  private java.lang.Boolean sendResolved;
  private java.lang.String toParty;
  private java.lang.String toTag;
  private java.lang.String toUser;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getAgentID() {
    return this.agentID;
  }
  public A withAgentID(java.lang.String agentID) {
    this.agentID=agentID; return (A) this;
  }
  public java.lang.Boolean hasAgentID() {
    return this.agentID != null;
  }
  
  /**
   * Method is deprecated. use withAgentID instead.
   */
  @java.lang.Deprecated
  public A withNewAgentID(java.lang.String arg0) {
    return (A)withAgentID(new String(arg0));
  }
  public io.fabric8.kubernetes.api.model.SecretKeySelector getApiSecret() {
    return this.apiSecret;
  }
  public A withApiSecret(io.fabric8.kubernetes.api.model.SecretKeySelector apiSecret) {
    this.apiSecret=apiSecret; return (A) this;
  }
  public java.lang.Boolean hasApiSecret() {
    return this.apiSecret != null;
  }
  public A withNewApiSecret(java.lang.String key,java.lang.String name,java.lang.Boolean optional) {
    return (A)withApiSecret(new SecretKeySelector(key, name, optional));
  }
  public java.lang.String getApiURL() {
    return this.apiURL;
  }
  public A withApiURL(java.lang.String apiURL) {
    this.apiURL=apiURL; return (A) this;
  }
  public java.lang.Boolean hasApiURL() {
    return this.apiURL != null;
  }
  
  /**
   * Method is deprecated. use withApiURL instead.
   */
  @java.lang.Deprecated
  public A withNewApiURL(java.lang.String arg0) {
    return (A)withApiURL(new String(arg0));
  }
  public java.lang.String getCorpID() {
    return this.corpID;
  }
  public A withCorpID(java.lang.String corpID) {
    this.corpID=corpID; return (A) this;
  }
  public java.lang.Boolean hasCorpID() {
    return this.corpID != null;
  }
  
  /**
   * Method is deprecated. use withCorpID instead.
   */
  @java.lang.Deprecated
  public A withNewCorpID(java.lang.String arg0) {
    return (A)withCorpID(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildHttpConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig getHttpConfig() {
    return this.httpConfig!=null?this.httpConfig.build():null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig buildHttpConfig() {
    return this.httpConfig!=null?this.httpConfig.build():null;
  }
  public A withHttpConfig(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig httpConfig) {
    _visitables.get("httpConfig").remove(this.httpConfig);
    if (httpConfig!=null){ this.httpConfig= new io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder(httpConfig); _visitables.get("httpConfig").add(this.httpConfig);} return (A) this;
  }
  public java.lang.Boolean hasHttpConfig() {
    return this.httpConfig != null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfigFluent.HttpConfigNested<A> withNewHttpConfig() {
    return new io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfigFluentImpl.HttpConfigNestedImpl();
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfigFluent.HttpConfigNested<A> withNewHttpConfigLike(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig item) {
    return new io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfigFluentImpl.HttpConfigNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfigFluent.HttpConfigNested<A> editHttpConfig() {
    return withNewHttpConfigLike(getHttpConfig());
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfigFluent.HttpConfigNested<A> editOrNewHttpConfig() {
    return withNewHttpConfigLike(getHttpConfig() != null ? getHttpConfig(): new io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder().build());
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfigFluent.HttpConfigNested<A> editOrNewHttpConfigLike(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig item) {
    return withNewHttpConfigLike(getHttpConfig() != null ? getHttpConfig(): item);
  }
  public java.lang.String getMessage() {
    return this.message;
  }
  public A withMessage(java.lang.String message) {
    this.message=message; return (A) this;
  }
  public java.lang.Boolean hasMessage() {
    return this.message != null;
  }
  
  /**
   * Method is deprecated. use withMessage instead.
   */
  @java.lang.Deprecated
  public A withNewMessage(java.lang.String arg0) {
    return (A)withMessage(new String(arg0));
  }
  public java.lang.String getMessageType() {
    return this.messageType;
  }
  public A withMessageType(java.lang.String messageType) {
    this.messageType=messageType; return (A) this;
  }
  public java.lang.Boolean hasMessageType() {
    return this.messageType != null;
  }
  
  /**
   * Method is deprecated. use withMessageType instead.
   */
  @java.lang.Deprecated
  public A withNewMessageType(java.lang.String arg0) {
    return (A)withMessageType(new String(arg0));
  }
  public java.lang.Boolean getSendResolved() {
    return this.sendResolved;
  }
  public A withSendResolved(java.lang.Boolean sendResolved) {
    this.sendResolved=sendResolved; return (A) this;
  }
  public java.lang.Boolean hasSendResolved() {
    return this.sendResolved != null;
  }
  public java.lang.String getToParty() {
    return this.toParty;
  }
  public A withToParty(java.lang.String toParty) {
    this.toParty=toParty; return (A) this;
  }
  public java.lang.Boolean hasToParty() {
    return this.toParty != null;
  }
  
  /**
   * Method is deprecated. use withToParty instead.
   */
  @java.lang.Deprecated
  public A withNewToParty(java.lang.String arg0) {
    return (A)withToParty(new String(arg0));
  }
  public java.lang.String getToTag() {
    return this.toTag;
  }
  public A withToTag(java.lang.String toTag) {
    this.toTag=toTag; return (A) this;
  }
  public java.lang.Boolean hasToTag() {
    return this.toTag != null;
  }
  
  /**
   * Method is deprecated. use withToTag instead.
   */
  @java.lang.Deprecated
  public A withNewToTag(java.lang.String arg0) {
    return (A)withToTag(new String(arg0));
  }
  public java.lang.String getToUser() {
    return this.toUser;
  }
  public A withToUser(java.lang.String toUser) {
    this.toUser=toUser; return (A) this;
  }
  public java.lang.Boolean hasToUser() {
    return this.toUser != null;
  }
  
  /**
   * Method is deprecated. use withToUser instead.
   */
  @java.lang.Deprecated
  public A withNewToUser(java.lang.String arg0) {
    return (A)withToUser(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    WeChatConfigFluentImpl that = (WeChatConfigFluentImpl) o;
    if (agentID != null ? !agentID.equals(that.agentID) :that.agentID != null) return false;
    if (apiSecret != null ? !apiSecret.equals(that.apiSecret) :that.apiSecret != null) return false;
    if (apiURL != null ? !apiURL.equals(that.apiURL) :that.apiURL != null) return false;
    if (corpID != null ? !corpID.equals(that.corpID) :that.corpID != null) return false;
    if (httpConfig != null ? !httpConfig.equals(that.httpConfig) :that.httpConfig != null) return false;
    if (message != null ? !message.equals(that.message) :that.message != null) return false;
    if (messageType != null ? !messageType.equals(that.messageType) :that.messageType != null) return false;
    if (sendResolved != null ? !sendResolved.equals(that.sendResolved) :that.sendResolved != null) return false;
    if (toParty != null ? !toParty.equals(that.toParty) :that.toParty != null) return false;
    if (toTag != null ? !toTag.equals(that.toTag) :that.toTag != null) return false;
    if (toUser != null ? !toUser.equals(that.toUser) :that.toUser != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(agentID,  apiSecret,  apiURL,  corpID,  httpConfig,  message,  messageType,  sendResolved,  toParty,  toTag,  toUser,  additionalProperties,  super.hashCode());
  }
  public class HttpConfigNestedImpl<N> extends io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigFluentImpl<io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfigFluent.HttpConfigNested<N>> implements io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfigFluent.HttpConfigNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    HttpConfigNestedImpl(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig item) {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder(this, item);
    }
    HttpConfigNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder(this);
    }
    io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder builder;
    public N and() {
      return (N) WeChatConfigFluentImpl.this.withHttpConfig(builder.build());
    }
    public N endHttpConfig() {
      return and();
    }
    
  }
  
}

==> openshift-model-monitoring-5.12.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/WeChatConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.SecretKeySelector;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class WeChatConfigFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfigFluent<A>{
  public WeChatConfigFluentImpl() {
  }
  public WeChatConfigFluentImpl(io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfig instance) {
    this.withAgentID(instance.getAgentID()); 
    this.withApiSecret(instance.getApiSecret()); 
    this.withApiURL(instance.getApiURL()); 
    this.withCorpID(instance.getCorpID()); 
    this.withHttpConfig(instance.getHttpConfig()); 
    this.withMessage(instance.getMessage()); 
    this.withMessageType(instance.getMessageType()); 
    this.withSendResolved(instance.getSendResolved()); 
    this.withToParty(instance.getToParty()); 
    this.withToTag(instance.getToTag()); 
    this.withToUser(instance.getToUser()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String agentID;
  private io.fabric8.kubernetes.api.model.SecretKeySelector apiSecret;
  private java.lang.String apiURL;
  private java.lang.String corpID;
  private io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder httpConfig;
  private java.lang.String message;
  private java.lang.String messageType;
  private java.lang.Boolean sendResolved;
  private java.lang.String toParty;
  private java.lang.String toTag;
  private java.lang.String toUser;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getAgentID() {
    return this.agentID;
  }
  public A withAgentID(java.lang.String agentID) {
    this.agentID=agentID; return (A) this;
  }
  public java.lang.Boolean hasAgentID() {
    return this.agentID != null;
  }
  
  /**
   * Method is deprecated. use withAgentID instead.
   */
  @java.lang.Deprecated
  public A withNewAgentID(java.lang.String arg0) {
    return (A)withAgentID(new String(arg0));
  }
  public io.fabric8.kubernetes.api.model.SecretKeySelector getApiSecret() {
    return this.apiSecret;
  }
  public A withApiSecret(io.fabric8.kubernetes.api.model.SecretKeySelector apiSecret) {
    this.apiSecret=apiSecret; return (A) this;
  }
  public java.lang.Boolean hasApiSecret() {
    return this.apiSecret != null;
  }
  public A withNewApiSecret(java.lang.String key,java.lang.String name,java.lang.Boolean optional) {
    return (A)withApiSecret(new SecretKeySelector(key, name, optional));
  }
  public java.lang.String getApiURL() {
    return this.apiURL;
  }
  public A withApiURL(java.lang.String apiURL) {
    this.apiURL=apiURL; return (A) this;
  }
  public java.lang.Boolean hasApiURL() {
    return this.apiURL != null;
  }
  
  /**
   * Method is deprecated. use withApiURL instead.
   */
  @java.lang.Deprecated
  public A withNewApiURL(java.lang.String arg0) {
    return (A)withApiURL(new String(arg0));
  }
  public java.lang.String getCorpID() {
    return this.corpID;
  }
  public A withCorpID(java.lang.String corpID) {
    this.corpID=corpID; return (A) this;
  }
  public java.lang.Boolean hasCorpID() {
    return this.corpID != null;
  }
  
  /**
   * Method is deprecated. use withCorpID instead.
   */
  @java.lang.Deprecated
  public A withNewCorpID(java.lang.String arg0) {
    return (A)withCorpID(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildHttpConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig getHttpConfig() {
    return this.httpConfig!=null?this.httpConfig.build():null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig buildHttpConfig() {
    return this.httpConfig!=null?this.httpConfig.build():null;
  }
  public A withHttpConfig(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig httpConfig) {
    _visitables.get("httpConfig").remove(this.httpConfig);
    if (httpConfig!=null){ this.httpConfig= new io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder(httpConfig); _visitables.get("httpConfig").add(this.httpConfig);} return (A) this;
  }
  public java.lang.Boolean hasHttpConfig() {
    return this.httpConfig != null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfigFluent.HttpConfigNested<A> withNewHttpConfig() {
    return new io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfigFluentImpl.HttpConfigNestedImpl();
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfigFluent.HttpConfigNested<A> withNewHttpConfigLike(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig item) {
    return new io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfigFluentImpl.HttpConfigNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfigFluent.HttpConfigNested<A> editHttpConfig() {
    return withNewHttpConfigLike(getHttpConfig());
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfigFluent.HttpConfigNested<A> editOrNewHttpConfig() {
    return withNewHttpConfigLike(getHttpConfig() != null ? getHttpConfig(): new io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder().build());
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfigFluent.HttpConfigNested<A> editOrNewHttpConfigLike(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig item) {
    return withNewHttpConfigLike(getHttpConfig() != null ? getHttpConfig(): item);
  }
  public java.lang.String getMessage() {
    return this.message;
  }
  public A withMessage(java.lang.String message) {
    this.message=message; return (A) this;
  }
  public java.lang.Boolean hasMessage() {
    return this.message != null;
  }
  
  /**
   * Method is deprecated. use withMessage instead.
   */
  @java.lang.Deprecated
  public A withNewMessage(java.lang.String arg0) {
    return (A)withMessage(new String(arg0));
  }
  public java.lang.String getMessageType() {
    return this.messageType;
  }
  public A withMessageType(java.lang.String messageType) {
    this.messageType=messageType; return (A) this;
  }
  public java.lang.Boolean hasMessageType() {
    return this.messageType != null;
  }
  
  /**
   * Method is deprecated. use withMessageType instead.
   */
  @java.lang.Deprecated
  public A withNewMessageType(java.lang.String arg0) {
    return (A)withMessageType(new String(arg0));
  }
  public java.lang.Boolean getSendResolved() {
    return this.sendResolved;
  }
  public A withSendResolved(java.lang.Boolean sendResolved) {
    this.sendResolved=sendResolved; return (A) this;
  }
  public java.lang.Boolean hasSendResolved() {
    return this.sendResolved != null;
  }
  public java.lang.String getToParty() {
    return this.toParty;
  }
  public A withToParty(java.lang.String toParty) {
    this.toParty=toParty; return (A) this;
  }
  public java.lang.Boolean hasToParty() {
    return this.toParty != null;
  }
  
  /**
   * Method is deprecated. use withToParty instead.
   */
  @java.lang.Deprecated
  public A withNewToParty(java.lang.String arg0) {
    return (A)withToParty(new String(arg0));
  }
  public java.lang.String getToTag() {
    return this.toTag;
  }
  public A withToTag(java.lang.String toTag) {
    this.toTag=toTag; return (A) this;
  }
  public java.lang.Boolean hasToTag() {
    return this.toTag != null;
  }
  
  /**
   * Method is deprecated. use withToTag instead.
   */
  @java.lang.Deprecated
  public A withNewToTag(java.lang.String arg0) {
    return (A)withToTag(new String(arg0));
  }
  public java.lang.String getToUser() {
    return this.toUser;
  }
  public A withToUser(java.lang.String toUser) {
    this.toUser=toUser; return (A) this;
  }
  public java.lang.Boolean hasToUser() {
    return this.toUser != null;
  }
  
  /**
   * Method is deprecated. use withToUser instead.
   */
  @java.lang.Deprecated
  public A withNewToUser(java.lang.String arg0) {
    return (A)withToUser(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    WeChatConfigFluentImpl that = (WeChatConfigFluentImpl) o;
    if (agentID != null ? !agentID.equals(that.agentID) :that.agentID != null) return false;
    if (apiSecret != null ? !apiSecret.equals(that.apiSecret) :that.apiSecret != null) return false;
    if (apiURL != null ? !apiURL.equals(that.apiURL) :that.apiURL != null) return false;
    if (corpID != null ? !corpID.equals(that.corpID) :that.corpID != null) return false;
    if (httpConfig != null ? !httpConfig.equals(that.httpConfig) :that.httpConfig != null) return false;
    if (message != null ? !message.equals(that.message) :that.message != null) return false;
    if (messageType != null ? !messageType.equals(that.messageType) :that.messageType != null) return false;
    if (sendResolved != null ? !sendResolved.equals(that.sendResolved) :that.sendResolved != null) return false;
    if (toParty != null ? !toParty.equals(that.toParty) :that.toParty != null) return false;
    if (toTag != null ? !toTag.equals(that.toTag) :that.toTag != null) return false;
    if (toUser != null ? !toUser.equals(that.toUser) :that.toUser != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(agentID,  apiSecret,  apiURL,  corpID,  httpConfig,  message,  messageType,  sendResolved,  toParty,  toTag,  toUser,  additionalProperties,  super.hashCode());
  }
  public class HttpConfigNestedImpl<N> extends io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigFluentImpl<io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfigFluent.HttpConfigNested<N>> implements io.fabric8.openshift.api.model.monitoring.v1alpha1.WeChatConfigFluent.HttpConfigNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    HttpConfigNestedImpl(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig item) {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder(this, item);
    }
    HttpConfigNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder(this);
    }
    io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder builder;
    public N and() {
      return (N) WeChatConfigFluentImpl.this.withHttpConfig(builder.build());
    }
    public N endHttpConfig() {
      return and();
    }
    
  }
  
}
